Struct longbridge_wscli::RateLimit
source · pub struct RateLimit {
pub interval: Duration,
pub initial: usize,
pub max: usize,
pub refill: usize,
}Expand description
Rate limiter config
Fields
interval: DurationThe time duration between which we add refill number to the bucket
initial: usizeThe initial number of tokens
max: usizeThe max number of tokens to use
refill: usizeThe number of tokens to add at each interval interval